# Fence Agent for ePowerSwitch

## Description
fence_eps is an I/O Fencing agent which can be used with the
ePowerSwitch 8M+/8XM R2 power switch to fence connected machines. Fence
agent works ONLY on devices with enabled hidden page feature. You may
try to update the firmware to achive this functionality.

Agent basically works by connecting to hidden page and pass appropriate
arguments to GET request. This means, that hidden page feature must be
enabled and properly configured.

Supported are single ports and port groups, username and/or password
(not required).


## Supported Options
```
Usage:
	fence_eps_ws [options]
Options:
   -a, --ip=[ip]                  IP address or hostname of fencing device
   -l, --username=[name]          Login name
   -p, --password=[password]      Login password or passphrase
   -n, --plug=[id]                Physical plug number on device, UUID or
                                        identification of machine
   -c, --page=[page]              Name of hidden page (default: hidden.htm)
   -u, --ipport=[port]            TCP/UDP port to use (default 80)
   -4, --inet4-only               Forces agent to use IPv4 addresses only
   -6, --inet6-only               Forces agent to use IPv6 addresses only
   -S, --password-script=[script] Script to run to retrieve password
   -o, --action=[action]          Action: on, off, reboot (default), status, list,
                                        list-status, monitor, metadata, manpage or
                                        validate-all
   -q, --quiet                    Disable logging to stderr. Does not affect
                                        --verbose or --debug-file or logging to
                                        syslog.
   -v, --verbose                  Verbose mode
   -D, --debug-file=[debugfile]   Debugging to output file
   -V, --version                  Display version information and exit
   -h, --help                     Display this help and exit
   -C, --separator=[char]         Separator for CSV created by 'list' operation
   --power-timeout=[seconds]      Test X seconds for status change after ON/OFF
   --shell-timeout=[seconds]      Wait X seconds for cmd prompt after issuing command
   --login-timeout=[seconds]      Wait X seconds for cmd prompt after login
   --power-wait=[seconds]         Wait X seconds after issuing ON/OFF
   --delay=[seconds]              Wait X seconds before fencing is started
   --retry-on=[attempts]          Count of attempts to retry power on
```

## Direct Fencing
Direct fence command: `fence_eps_ws -a <ip> [-l <username> -S <path to password script>] -o <action> -n <port>`


## Fencing With `pcs` Tools
```
Stonith options:
  inet4_only: Forces agent to use IPv4 addresses only
  inet6_only: Forces agent to use IPv6 addresses only
  ip (required): IP address or hostname of fencing device
  ipport: TCP/UDP port to use for connection with device
  page: Name of hidden page
  password: Login password or passphrase
  password_script: Script to run to retrieve password
  plug: Physical plug number on device, UUID or identification of machine
  username: Login name
  quiet: Disable logging to stderr. Does not affect --verbose or --debug-file or logging to syslog.
  verbose: Verbose mode
  debug_file: Write debug information to given file
  separator: Separator for CSV created by 'list' operation
  delay: Wait X seconds before fencing is started
  login_timeout: Wait X seconds for cmd prompt after login
  power_timeout: Test X seconds for status change after ON/OFF
  power_wait: Wait X seconds after issuing ON/OFF
  shell_timeout: Wait X seconds for cmd prompt after issuing command
  retry_on: Count of attempts to retry power on
  pcmk_host_map: A mapping of host names to ports numbers for devices that do not support host names. Eg.
                 node1:1;node2:2,3 would tell the cluster to use port 1 for node1 and ports 2 and 3 for node2
  pcmk_host_list: A list of machines controlled by this device (Optional unless pcmk_host_check=static-list).
  pcmk_host_check: How to determine which machines are controlled by the device. Allowed values: dynamic-list (query
                   the device via the 'list' command), static-list (check the pcmk_host_list attribute), status (query
                   the device via the 'status' command), none (assume every device can fence every machine)
  pcmk_delay_max: Enable a random delay for stonith actions and specify the maximum of random delay. This prevents
                  double fencing when using slow devices such as sbd. Use this to enable a random delay for stonith
                  actions. The overall delay is derived from this random delay value adding a static delay so that the
                  sum is kept below the maximum delay.
  pcmk_delay_base: Enable a base delay for stonith actions and specify base delay value. This prevents double fencing
                   when different delays are configured on the nodes. Use this to enable a static delay for stonith
                   actions. The overall delay is derived from a random delay value adding this static delay so that the
                   sum is kept below the maximum delay.
  pcmk_action_limit: The maximum number of actions can be performed in parallel on this device Cluster property
                     concurrent-fencing=true needs to be configured first. Then use this to specify the maximum number
                     of actions can be performed in parallel on this device. -1 is unlimited.
```

### Portmap
Portmap is supported. Use
`pcmk_host_map='<node1>:<port1>,<port2>[,...];<node2:<port1>,<port2>[,...][;...]`. `<port>`
may not contain colons - just leave them away, this agent supports this.

### Fencing With Ansible Role `ansible-rhcs-cluster-centos8`
Just add a a section to the cluster node configuration containing the
desired options.

```
fence_devices:
  - name: <name>
    type: fence_eps_ws
    options: "ip=<ip> login=<username> password_script=<path to password script> pcmk_host_map='<node>:<port1>,<port2>' meta provides=unfencing"
```

`<port>` may not contain colons - just leave them away, this agent supports this.


## Logo
Sources:
+ https://svgsilh.com/de/image/1097655.html
+ https://www.neol.com/fileadmin/images/other/epowerswitch-logo.png
